{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": "${\n  return [\n    {\n      \"class\": \"Directory\",\n      \"basename\": inputs.genome_dir,\n      \"listing\": [],\n      \"writable\": true}\n  ]\n}\n"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "scidap/star:v2.7.5c"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--genomeChainFiles"
                    },
                    "doc": "string: chain files for genomic liftover\n",
                    "id": "#star-genomegenerate.cwl/genome_chain_files"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--genomeChrBinNbits"
                    },
                    "doc": "int: =log2(chrBin), where chrBin is the size of the bins for genome\nstorage: each chromosome will occupy an integer number of bins\n",
                    "id": "#star-genomegenerate.cwl/genome_chr_bin_n_bits"
                },
                {
                    "type": "string",
                    "default": "star_indices",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--genomeDir"
                    },
                    "doc": "Directory where genome index files are stored",
                    "id": "#star-genomegenerate.cwl/genome_dir"
                },
                {
                    "type": [
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "position": 1,
                        "itemSeparator": " ",
                        "prefix": "--genomeFastaFiles"
                    },
                    "doc": "string(s): path(s) to the fasta files with genomic sequences for genome\ngeneration, separated by spaces. Only used if runMode==genomeGenerate.\nThese files should be plain text FASTA files, they *cannot* be zipped.\n",
                    "id": "#star-genomegenerate.cwl/genome_fasta_files"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--genomeSAindexNbases"
                    },
                    "doc": "int: length (bases) of the SA pre-indexing string. Typically between 10 and\n15. Longer strings will use much more memory, but allow faster searches.\n",
                    "id": "#star-genomegenerate.cwl/genome_sa_index_n_bases"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--genomeSAsparseD"
                    },
                    "doc": "int>0: suffux array sparsity, i.e. distance between indices: use bigger\nnumbers to decrease needed RAM at the cost of mapping speed reduction\n",
                    "id": "#star-genomegenerate.cwl/genome_sa_sparse_d"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--genomeSuffixLengthMax"
                    },
                    "doc": "int: maximum length of the suffixes, has to be longer than read length. -1 = infinite.\n",
                    "id": "#star-genomegenerate.cwl/genome_suffix_length_max"
                },
                {
                    "type": [
                        "null",
                        "long"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--limitGenomeGenerateRAM"
                    },
                    "doc": "31000000000\nint>0: maximum available RAM (bytes) for genome generation\n",
                    "id": "#star-genomegenerate.cwl/limit_genome_generate_ram"
                },
                {
                    "type": [
                        "null",
                        "long"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--limitIObufferSize"
                    },
                    "doc": "150000000\nint>0: max available buffers size (bytes) for input/output, per thread\n",
                    "id": "#star-genomegenerate.cwl/limit_io_buffer_size"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--parametersFiles"
                    },
                    "doc": "string: name of a user-defined parameters file, \"-\": none. Can only be\ndefined on the command line.\n",
                    "id": "#star-genomegenerate.cwl/parameters_files"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--runDirPerm"
                    },
                    "doc": "User_RWX\nstring: permissions for the directories created at the run-time.\nUser_RWX ... user-read/write/execute\nAll_RWX  ... all-read/write/execute (same as chmod 777)\n",
                    "id": "#star-genomegenerate.cwl/run_dir_perm"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--sjdbGTFchrPrefix"
                    },
                    "doc": "string: prefix for chromosome names in a GTF file (e.g. 'chr' for using ENSMEBL annotations with UCSC genomes)\n",
                    "id": "#star-genomegenerate.cwl/sjdb_gtf_chr_prefix"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--sjdbGTFfeatureExon"
                    },
                    "doc": "exon\nstring: feature type in GTF file to be used as exons for building\ntranscripts\n",
                    "id": "#star-genomegenerate.cwl/sjdb_gtf_feature_exon"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--sjdbGTFfile"
                    },
                    "doc": "string: path to the GTF file with annotations\n",
                    "id": "#star-genomegenerate.cwl/sjdb_gtf_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--sjdbGTFtagExonParentGene"
                    },
                    "doc": "gene_id\nstring: tag name to be used as exons'' gene-parents (default \"gene_id\" works\nfor GTF files)\n",
                    "id": "#star-genomegenerate.cwl/sjdb_gtf_tag_exon_parent_gene"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--sjdbGTFtagExonParentTranscript"
                    },
                    "doc": "transcript_id\nstring: tag name to be used as exons' transcript-parents (default\n\"transcript_id\" works for GTF files)\n",
                    "id": "#star-genomegenerate.cwl/sjdb_gtf_tag_exon_parent_transcript"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--sjdbOverhang"
                    },
                    "doc": "default: 100\nint>0: length of the donor/acceptor sequence on each side of the junctions,\nideally = (mate_length - 1)\n",
                    "id": "#star-genomegenerate.cwl/sjdb_overhang"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--sysShell"
                    },
                    "doc": "string: path to the shell binary, preferrably bash, e.g. /bin/bash.\n- ... the default shell is executed, typically /bin/sh. This was reported to fail on some Ubuntu systems - then you need to specify path to bash.\n",
                    "id": "#star-genomegenerate.cwl/sys_shell"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--runThreadN"
                    },
                    "doc": "1\nint: number of threads to run STAR\n",
                    "id": "#star-genomegenerate.cwl/threads"
                }
            ],
            "baseCommand": [
                "STAR",
                "--runMode",
                "genomeGenerate"
            ],
            "stdout": "star_build_stdout.log",
            "stderr": "star_build_stderr.log",
            "doc": "Tool returns directory with indices generated by STAR. If genome_dir input is not provided,\nuse default output directory name star_indices.\nOutput chr_name_length should not be moved outside the indices folder.\n",
            "id": "#star-genomegenerate.cwl",
            "http://schema.org/name": "star-genomegenerate",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/star-genomegenerate.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#star-metadata.yaml",
                "http://schema.org/name": "STAR",
                "http://schema.org/about": "Aligns RNA-seq reads to a reference genome using uncompressed suffix arrays.\nSTAR has a potential for accurately aligning long (several kilobases) reads that\nare emerging from the third-generation sequencing technologies\n",
                "http://schema.org/url": "https://github.com/alexdobin/STAR",
                "http://schema.org/codeRepository": "https://github.com/alexdobin/STAR",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/GPL-3.0"
                ],
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "v2.5.3a",
                    "http://schema.org/applicationCategory": "command line tool"
                },
                "http://schema.org/programmingLanguage": "C++",
                "http://schema.org/publication": [
                    {
                        "class": "http://schema.org/ScholarlyArticle",
                        "id": "#star-metadata.yaml/ 10.1093/bioinformatics/bts635",
                        "datePublished": "1 January 2013",
                        "http://schema.org/name": "STAR: ultrafast universal RNA-seq aligner",
                        "http://schema.org/author": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Alexander Dobin"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Carrie A. Davis"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Felix Schlesinger"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Jorg Drenkow"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Chris Zaleski"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Sonali Jha"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Philippe Batut"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Mark Chaisson"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Thomas R. Gingeras1"
                            }
                        ],
                        "http://schema.org/url": "https://academic.oup.com/bioinformatics/article/29/1/15/272537"
                    }
                ],
                "http://schema.org/discussionUrl": [
                    "https://github.com/alexdobin/STAR/issues"
                ],
                "http://schema.org/creator": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Cold Spring Harbor Laboratory, Cold Spring Harbor, NY, USA",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Alexander Dobin",
                                "http://schema.org/description": "main author"
                            }
                        ]
                    }
                ]
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.genome_dir + \"/chrNameLength.txt\")"
                    },
                    "id": "#star-genomegenerate.cwl/chrom_length"
                },
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.genome_dir)"
                    },
                    "id": "#star-genomegenerate.cwl/indices_folder"
                },
                {
                    "type": "File",
                    "id": "#star-genomegenerate.cwl/stderr_log",
                    "outputBinding": {
                        "glob": "star_build_stderr.log"
                    }
                },
                {
                    "type": "File",
                    "id": "#star-genomegenerate.cwl/stdout_log",
                    "outputBinding": {
                        "glob": "star_build_stdout.log"
                    }
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "sd:metadata": [
                "../metadata/indices-header.cwl"
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_2306",
                    "label": "GTF annotation file",
                    "doc": "GTF annotation file",
                    "id": "#main/annotation_gtf_file"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "label": "Reference genome FASTA file",
                    "doc": "Reference genome FASTA file. Includes all chromosomes",
                    "id": "#main/fasta_file"
                },
                {
                    "type": "string",
                    "label": "Genome type",
                    "doc": "Genome type, such as mm10, hg19, hg38, etc",
                    "id": "#main/genome"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "label": "Number of bins allocated for each chromosome",
                    "doc": "If you are using a genome with a large (>5,000) number of references (chrosomes/sca\ufb00olds), you may need to reduce the\n--genomeChrBinNbits to reduce RAM consumption. For a genome with large number of contigs, it is recommended to scale\nthis parameter as min(18, log2[max(GenomeLength/NumberOfReferences,ReadLength)]).\ndefault: 18\n",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/genome_chr_bin_n_bits"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "label": "Length of SA pre-indexing string",
                    "doc": "Length (bases) of the SA pre-indexing string. Typically between 10 and 15. Longer strings will use much more memory,\nbut allow faster searches. For small genomes, the parameter \u2013genomeSAindexNbases must be scaled down to\nmin(14, log2(GenomeLength)/2 - 1). For example, for 1 megaBase genome, this is equal to 9, for 100 kiloBase genome,\nthis is equal to 7.\ndefault: 14\n",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/genome_sa_index_n_bases"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2,
                    "label": "Suffix array sparsity (use 2 to decrease needed RAM)",
                    "doc": "Suffix array sparsity, i.e. distance between indices: use bigger\nnumbers to decrease needed RAMat the cost of mapping speed reduction\"\n",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/genome_sa_sparse_d"
                },
                {
                    "type": [
                        "null",
                        "long"
                    ],
                    "label": "Limit maximum available RAM (bytes) for genome generation",
                    "doc": "Maximum available RAM (bytes) for genome generation. Default 31000000000",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/limit_genome_generate_ram"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "label": "Number of threads",
                    "doc": "Number of threads for those steps that support multithreading",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2330",
                    "outputSource": "#main/star_generate_indices/chrom_length",
                    "label": "Chromosome length file",
                    "doc": "Chromosome length file",
                    "id": "#main/chrom_length_file"
                },
                {
                    "type": "Directory",
                    "outputSource": "#main/star_generate_indices/indices_folder",
                    "label": "STAR indices",
                    "doc": "STAR generated indices folder",
                    "id": "#main/indices_folder"
                },
                {
                    "type": "File",
                    "label": "STAR stderr log",
                    "doc": "STAR generated stderr log",
                    "outputSource": "#main/star_generate_indices/stderr_log",
                    "id": "#main/stderr_log"
                },
                {
                    "type": "File",
                    "label": "STAR stdout log",
                    "doc": "STAR generated stdout log",
                    "outputSource": "#main/star_generate_indices/stdout_log",
                    "id": "#main/stdout_log"
                }
            ],
            "steps": [
                {
                    "run": "#star-genomegenerate.cwl",
                    "in": [
                        {
                            "source": "#main/genome_chr_bin_n_bits",
                            "id": "#main/star_generate_indices/genome_chr_bin_n_bits"
                        },
                        {
                            "source": "#main/genome",
                            "id": "#main/star_generate_indices/genome_dir"
                        },
                        {
                            "source": "#main/fasta_file",
                            "id": "#main/star_generate_indices/genome_fasta_files"
                        },
                        {
                            "source": "#main/genome_sa_index_n_bases",
                            "id": "#main/star_generate_indices/genome_sa_index_n_bases"
                        },
                        {
                            "source": "#main/genome_sa_sparse_d",
                            "id": "#main/star_generate_indices/genome_sa_sparse_d"
                        },
                        {
                            "source": "#main/limit_genome_generate_ram",
                            "id": "#main/star_generate_indices/limit_genome_generate_ram"
                        },
                        {
                            "source": "#main/annotation_gtf_file",
                            "id": "#main/star_generate_indices/sjdb_gtf_file"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/star_generate_indices/threads"
                        }
                    ],
                    "out": [
                        "#main/star_generate_indices/indices_folder",
                        "#main/star_generate_indices/chrom_length",
                        "#main/star_generate_indices/stdout_log",
                        "#main/star_generate_indices/stderr_log"
                    ],
                    "id": "#main/star_generate_indices"
                }
            ],
            "label": "Build STAR indices",
            "doc": "Workflow runs [STAR](https://github.com/alexdobin/STAR) v2.5.3a (03/17/2017) PMID: [23104886](https://www.ncbi.nlm.nih.gov/pubmed/23104886)\nto build indices for reference genome provided in a single FASTA file as fasta_file input and GTF annotation file from annotation_gtf_file input.\nGenerated indices are saved in a folder with the name that corresponds to the input genome.\n",
            "id": "#main",
            "http://schema.org/name": "Build STAR indices",
            "http://schema.org/alternateName": "Generates indices for STAR v2.5.3a (03/17/2017)",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/barski-lab/workflows/master/workflows/scidap/star-index.cwl",
            "http://schema.org/codeRepository": "https://github.com/barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:michael.kotliar@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        },
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Andrey Kartashov",
                                            "http://schema.org/email": "mailto:Andrey.Kartashov@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0001-9102-5681"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://schema.org/version/latest/schema.rdf"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
